@@ -888,7 +888,7 @@ def to_geqdsk(eqm, t_in=0.):
         omfit_classes.omfit_eqdsk.OMFITgeqdsk objects.
     """
 
-    equ = coco2coco(eqm, cocos_out=1)
+    equ = cocos.coco2coco(eqm, cocos_out=1)
 
     jt = np.argmin(equ.time - t_in)
 
@@ -899,7 +899,7 @@ def to_geqdsk(eqm, t_in=0.):
     geq['CASE'] = np.array(['  CLISTE ', '    ', '   ', ' #' + str(equ.shot), '  %.2fs' % t_in, '  ' + 'EQI'], dtype='<U8')
     
     # separatrix R and Z
-    geq['RBBBS'], geq['ZBBBS'] = sf.rho2rz(equ, 0.999, t_in=equ.time[jt], all_lines=False)
+    geq['RBBBS'], geq['ZBBBS'] = rho2rz(equ, 0.999, t_in=equ.time[jt], all_lines=False)
 
     # R,Z of limiter structures
     geq['RLIM'] = [1.035, 1.050, 1.090, 1.140, 1.235, 1.340, 1.430, 1.505, 1.630, 1.770, 1.970, 2.110, 2.170, 2.205, 2.210, 2.175, 2.130, 2.010, 1.890, 1.705, 1.645, 1.580, 1.458, 1.325, 1.235, 1.286, 1.280, 1.245, 1.125, 1.060, 1.035]
