@@ -314,7 +314,7 @@ class WW:
                     sizes[1] = sizes[2]
             else:
                 nt = 1
-            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, sizes[0], sizes[1], sizes[2])
+            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, *sizes[:3])
             error  = ct.c_int32(0)
             name   = ct.c_char_p(areaname)
             lname  = ct.c_uint64(len(areaname))
@@ -333,7 +333,7 @@ class WW:
             if getError(error):
                 raise Exception('ww.shotfile.SetAreabase: Error writing areabase %s' %areaname)
             else:
-                logger.info('Written Areabase %s, sizes %d %d %d', areaname, sizes[0], sizes[1], sizes[2])
+                logger.info('Written Areabase %s, sizes %d %d %d', areaname, *sizes[:3])
 
 
     def SetParameter(self, set_name, par_name, data):
